[svn] GnuPG - r4237 - trunk/doc
svn author wk
cvs at cvs.gnupg.org
Mon Sep 4 16:53:21 CEST 2006
Author: wk
Date: 2006-09-04 16:53:20 +0200 (Mon, 04 Sep 2006)
New Revision: 4237
Modified:
trunk/doc/gpg-agent.texi
trunk/doc/gpg.texi
trunk/doc/gpgsm.texi
trunk/doc/yat2m.c
Log:
Some fixes as needed by dirmngr man pages
Modified: trunk/doc/gpg-agent.texi
===================================================================
--- trunk/doc/gpg-agent.texi 2006-09-04 11:00:52 UTC (rev 4236)
+++ trunk/doc/gpg-agent.texi 2006-09-04 14:53:20 UTC (rev 4237)
@@ -602,7 +602,7 @@
@c
@c Assuan Protocol
@c
- at mansect assuan
+ at manpause
@node Agent Protocol
@section Agent's Assuan Protocol
@@ -1051,3 +1051,13 @@
session. This command is useful to direct future pinentry invocations
to another screen. It is only required because there is no way in the
ssh-agent protocol to convey this information.
+
+
+ at mansect see also
+ at ifset isman
+ at command{gpg2}(1),
+ at command{gpgsm}(1),
+ at command{gpg-connect-agent}(1),
+ at command{scdaemon}(1)
+ at end ifset
+ at include see-also-note.texi
Modified: trunk/doc/gpg.texi
===================================================================
--- trunk/doc/gpg.texi 2006-09-04 11:00:52 UTC (rev 4236)
+++ trunk/doc/gpg.texi 2006-09-04 14:53:20 UTC (rev 4237)
@@ -2572,3 +2572,10 @@
locking without being root. The program drops root privileges as soon
as locked memory is allocated.
+ at mansect see also
+ at ifset isman
+ at command{gpgv}(1),
+ at command{gpgsm}(1),
+ at command{gpg-agent}(1)
+ at end ifset
+ at include see-also-note.texi
Modified: trunk/doc/gpgsm.texi
===================================================================
--- trunk/doc/gpgsm.texi 2006-09-04 11:00:52 UTC (rev 4236)
+++ trunk/doc/gpgsm.texi 2006-09-04 14:53:20 UTC (rev 4237)
@@ -773,7 +773,7 @@
@c *************** ASSSUAN *****************
@c *************** *****************
@c *******************************************
- at mansect assuan
+ at manpause
@node GPGSM Protocol
@section The Protocol the Server Mode Uses.
@@ -1071,3 +1071,10 @@
The certificates must be specified unambiguously otherwise an error is
returned.
+
+ at mansect see also
+ at ifset isman
+ at command{gpg2}(1),
+ at command{gpg-agent}(1)
+ at end ifset
+ at include see-also-note.texi
Modified: trunk/doc/yat2m.c
===================================================================
--- trunk/doc/yat2m.c 2006-09-04 11:00:52 UTC (rev 4236)
+++ trunk/doc/yat2m.c 2006-09-04 14:53:20 UTC (rev 4237)
@@ -41,7 +41,7 @@
left space. Processing starts after a "manpage" macro has been
seen. "mansect" identifies the section and yat2m make sure to
emit the sections in the proper order. Note that @mansect skips
- the next input line if that line begins with @subsection or
+ the next input line if that line begins with @section, @subsection or
@chapheading.
To insert verbatim troff markup, the follwing texinfo code may be
@@ -147,13 +147,14 @@
} thepage;
-/* The list of standard section names. */
+/* The list of standard section names. COMMANDS and ASSUAN are GnuPG
+ specific. */
static const char * const standard_sections[] =
{ "NAME", "SYNOPSIS", "DESCRIPTION",
"RETURN VALUE", "EXIT STATUS", "ERROR HANDLING", "ERRORS",
- "OPTIONS", "USAGE", "EXAMPLES", "FILES",
+ "COMMANDS", "OPTIONS", "USAGE", "EXAMPLES", "FILES",
"ENVIRONMENT", "DIAGNOSTICS", "SECURITY", "CONFORMING TO",
- "NOTES", "BUGS", "AUTHOR", "SEE ALSO", NULL };
+ "ASSUAN", "NOTES", "BUGS", "AUTHOR", "SEE ALSO", NULL };
/*-- Local prototypes. --*/
@@ -432,11 +433,13 @@
} cmdtbl[] = {
{ "command", 0, "\\fB", "\\fR" },
{ "code", 0, "\\fB", "\\fR" },
+ { "sc", 0, "\\fB", "\\fR" },
{ "var", 0, "\\fI", "\\fR" },
{ "samp", 0, "\n'", "'\n" },
{ "file", 0, "`\\fI","\\fR'" },
{ "env", 0, "`\\fI","\\fR'" },
{ "acronym", 0 },
+ { "dfn", 0 },
{ "option", 0, "\\fB", "\\fR" },
{ "example", 1, ".RS 2\n.nf\n" },
{ "smallexample", 1, ".RS 2\n.nf\n" },
@@ -456,6 +459,7 @@
{ "node", 1 },
{ "noindent", 0 },
{ "section", 1 },
+ { "chapter", 1 },
{ "subsection", 6, "\n.SS " },
{ "chapheading", 0},
{ "item", 2, ".TP\n.B " },
@@ -804,12 +808,11 @@
/* Parse one Texinfo file and create manpages according to the
embedded instructions. */
static void
-parse_file (const char *fname, FILE *fp, char **section_name)
+parse_file (const char *fname, FILE *fp, char **section_name, int in_pause)
{
char *line;
int lnr = 0;
int in_verbatim = 0;
- int in_pause = 0;
int skip_to_end = 0; /* Used to skip over menu entries. */
int skip_sect_line = 0; /* Skip after @mansect. */
@@ -832,7 +835,8 @@
if (skip_sect_line)
{
skip_sect_line = 0;
- if (!strncmp (line, "@subsection", 11)
+ if (!strncmp (line, "@section", 8)
+ || !strncmp (line, "@subsection", 11)
|| !strncmp (line, "@chapheading", 12))
continue;
}
@@ -943,7 +947,7 @@
incname, strerror (errno));
else
{
- parse_file (incname, incfp, section_name);
+ parse_file (incname, incfp, section_name, in_pause);
fclose (incfp);
}
free (incname);
@@ -971,7 +975,7 @@
{
char *section_name = NULL; /* Name of the current section or NULL
if not in a section. */
- parse_file (fname, fp, §ion_name);
+ parse_file (fname, fp, §ion_name, 0);
free (section_name);
finish_page ();
}
More information about the Gnupg-commits
mailing list